@@ -34,6 +34,7 @@
 #include <gnu_gama/local/newnetwork.h>
 #include <gnu_gama/local/acord.h>
 #include <gnu_gama/local/svg.h>
+#include <gnu_gama/local/html.h>
 
 #include <gnu_gama/local/results/text/approximate_coordinates.h>
 #include <gnu_gama/local/results/text/network_description.h>
@@ -67,13 +68,14 @@ int help()
 
     "Options:\n\n"
 
-    "--algorithm  svd | gso | cholesky | envelope\n"
-    "--language   en | ca | cz | du | es | fi | fr | hu | ru | ua \n"
+    "--algorithm  gso | svd | cholesky | envelope\n"
+    "--language   en | ca | cz | du | es | fi | fr | hu | ru | ua | zh\n"
     "--encoding   utf-8 | iso-8859-2 | iso-8859-2-flat | cp-1250 | cp-1251\n"
     "--angles     400 | 360\n"
     "--latitude   <latitude>\n"
     "--ellipsoid  <ellipsoid name>\n"
     "--text       adjustment_results.txt\n"
+    "--html       adjustment_results.html\n"
     "--xml        adjustment_results.xml\n"
     "--svg        network_configuration.svg\n"
     "--cov-band   covariance matrix of adjusted parameters in XML output\n"
@@ -95,13 +97,14 @@ int help()
 
     "Options:\n\n"
 
-    "--algorithm  svd | gso | cholesky | envelope\n"
-    "--language   en | ca | cz | du | es | fi | fr | hu | ru | ua \n"
+    "--algorithm  gso | svd | cholesky | envelope\n"
+    "--language   en | ca | cz | du | es | fi | fr | hu | ru | ua | zh\n"
     "--encoding   utf-8 | iso-8859-2 | iso-8859-2-flat | cp-1250 | cp-1251\n"
     "--angles     400 | 360\n"
     "--latitude   <latitude>\n"
     "--ellipsoid  <ellipsoid name>\n"
     "--text       adjustment_results.txt\n"
+    "--html       adjustment_results.html\n"
     "--xml        adjustment_results.xml\n"
     "--svg        network_configuration.svg\n"
     "--cov-band   covariance matrix of adjusted parameters in XML output\n"
@@ -133,6 +136,7 @@ int main(int argc, char **argv)
     const char* argv_ellipsoid = 0;
     const char* argv_latitude = 0;
     const char* argv_txtout = 0;
+    const char* argv_htmlout = 0;
     const char* argv_xmlout = 0;
     const char* argv_svgout = 0;
     const char* argv_obsout = 0;
@@ -178,6 +182,7 @@ int main(int argc, char **argv)
         else if (name == "ellipsoid" ) argv_ellipsoid = c;
         else if (name == "latitude"  ) argv_latitude = c;
         else if (name == "text"      ) argv_txtout = c;
+        else if (name == "html"      ) argv_htmlout = c;
         else if (name == "xml"       ) argv_xmlout = c;
         else if (name == "svg"       ) argv_svgout = c;
         else if (name == "obs"       ) argv_obsout = c;
@@ -208,9 +213,11 @@ int main(int argc, char **argv)
         else if (!strcmp("du", argv_lang)) set_gama_language(du);
         else if (!strcmp("es", argv_lang)) set_gama_language(es);
         else if (!strcmp("fr", argv_lang)) set_gama_language(fr);
+        else if (!strcmp("fi", argv_lang)) set_gama_language(fi);
         else if (!strcmp("hu", argv_lang)) set_gama_language(hu);
         else if (!strcmp("ru", argv_lang)) set_gama_language(ru);
         else if (!strcmp("ua", argv_lang)) set_gama_language(ua);
+        else if (!strcmp("zh", argv_lang)) set_gama_language(zh);
         else return help();
       }
 
@@ -255,8 +262,8 @@ int main(int argc, char **argv)
     if (argv_algo)
       {
         const std::string algorithm = argv_algo;
-        if (algorithm != "svd"      &&
-            algorithm != "gso"      &&
+        if (algorithm != "gso"      &&
+            algorithm != "svd"      &&
             algorithm != "cholesky" &&
             algorithm != "envelope" ) return help();
 
@@ -515,7 +522,23 @@ int main(int argc, char **argv)
           }
 
         // implicit output
-        if (!argv_txtout && !argv_xmlout) argv_xmlout = "-";
+        if (!argv_txtout && !argv_htmlout && !argv_xmlout) argv_xmlout = "-";
+
+        if (argv_htmlout)
+          {
+            GNU_gama::local::GamaLocalHTML html(IS);
+            html.exec();
+
+            if (!strcmp(argv_htmlout, "-"))
+              {
+                html.html(std::cout);
+              }
+            else
+              {
+                ofstream file(argv_htmlout);
+                html.html(file);
+              }
+          }
 
         if (argv_xmlout)
           {
