@@ -43,6 +43,8 @@ namespace GNU_gama { namespace local {
                     public LocalCoordinateSystem,
                     public AngularObservations
     {
+    public:
+      double xNorthAngle() const;
     };
 
 
@@ -56,7 +58,6 @@ namespace GNU_gama { namespace local {
         (lcs.right_handed_coordinates() && lcs.right_handed_angles());
     }
 
-
 }}   // namepsace GNU_gama::local
 
 
