@@ -1,15 +1,16 @@
 #ifndef GNU_gama_local___language__header_file_h
 #define GNU_gama_local___language__header_file_h
 
-namespace GNU_gama { namespace local {      /* slovnikar 1.11 */
+namespace GNU_gama { namespace local {      /* slovnikar 1.12 */
 
-enum gama_language { en, ca, cz, du, es, fi, fr, hu, ru, ua };
+enum gama_language { en, ca, cz, du, es, fi, fr, hu, ru, ua, zh };
 void set_gama_language(gama_language);
 
 extern const char* T_GKF_bad_angle;
 extern const char* T_GKF_bad_attribute_angle_dev;
 extern const char* T_GKF_bad_attribute_direction_dev;
 extern const char* T_GKF_bad_attribute_distance_dev;
+extern const char* T_GKF_bad_azimuth;
 extern const char* T_GKF_bad_coordinate_x;
 extern const char* T_GKF_bad_coordinate_y;
 extern const char* T_GKF_bad_direction;
@@ -59,6 +60,7 @@ extern const char* T_GKF_must_start_with_gama_xml;
 extern const char* T_GKF_no_observations_after_cov_mat;
 extern const char* T_GKF_point_must_define_xy_andor_z_inside_tag_coordinates;
 extern const char* T_GKF_undefined_attribute_of_angle;
+extern const char* T_GKF_undefined_attribute_of_azimuth;
 extern const char* T_GKF_undefined_attribute_of_coordinates;
 extern const char* T_GKF_undefined_attribute_of_cov_mat;
 extern const char* T_GKF_undefined_attribute_of_direction;
@@ -123,6 +125,7 @@ extern const char* T_GaMa_approx_header1;
 extern const char* T_GaMa_approx_observations;
 extern const char* T_GaMa_approx_separator;
 extern const char* T_GaMa_approx_total;
+extern const char* T_GaMa_azimuth;
 extern const char* T_GaMa_detected_singular_variables;
 extern const char* T_GaMa_direction;
 extern const char* T_GaMa_distance;
@@ -219,6 +222,36 @@ extern const char* T_GaMa_ydiff;
 extern const char* T_GaMa_z;
 extern const char* T_GaMa_z_angle;
 extern const char* T_GaMa_zdiff;
+extern const char* T_HTML_adjusted;
+extern const char* T_HTML_adjusted_observations;
+extern const char* T_HTML_approximate;
+extern const char* T_HTML_cc;
+extern const char* T_HTML_confidence;
+extern const char* T_HTML_correction;
+extern const char* T_HTML_d;
+extern const char* T_HTML_e_obs_adj;
+extern const char* T_HTML_f_proc;
+extern const char* T_HTML_g;
+extern const char* T_HTML_m;
+extern const char* T_HTML_md;
+extern const char* T_HTML_mean_error_ellipse;
+extern const char* T_HTML_mg;
+extern const char* T_HTML_mm;
+extern const char* T_HTML_mmcc;
+extern const char* T_HTML_mmss;
+extern const char* T_HTML_mp;
+extern const char* T_HTML_mxy;
+extern const char* T_HTML_observations;
+extern const char* T_HTML_observed;
+extern const char* T_HTML_points;
+extern const char* T_HTML_r;
+extern const char* T_HTML_rejected;
+extern const char* T_HTML_rstud;
+extern const char* T_HTML_ss;
+extern const char* T_HTML_stddev_confi;
+extern const char* T_HTML_value;
+extern const char* T_HTML_value_d;
+extern const char* T_HTML_value_g;
 extern const char* T_IE_internal_error;
 extern const char* T_LN_rm_huge_cov_xy;
 extern const char* T_LN_rm_huge_cov_xyz;
