@@ -1,7 +1,7 @@
 /* GNU Gama -- adjustment of geodetic networks
     Copyright (C) 1999, 2006, 2010  Ales Cepek <cepek@fsv.cvut.cz>
                   2011  Vaclav Petras <wenzeslaus@gmail.com>
-                  2012  Ales Cepek <cepek@gnu.org>
+                  2012, 2013  Ales Cepek <cepek@gnu.org>
 
    This file is part of the GNU Gama C++ library.
 
@@ -178,6 +178,11 @@ public:
         check(fabs(dz - obs->value())*1000);
     }
 
+    void visit(Azimuth* obs)
+    {
+        check(fabs(b(indm)*d0/(10*R2G)));
+    }
+
 private:
     Index indm;
     const LocalPoint* stan;
@@ -720,6 +725,17 @@ Double LocalNetwork::m_0()
 }
 
 
+Double LocalNetwork::m_0_aposteriori_value()
+{
+  vyrovnani_();
+  const int nadb = degrees_of_freedom();
+  if (nadb > 0)
+    return sqrt(trans_VWV()/nadb);
+  else
+    return 0;
+}
+
+
 Double LocalNetwork::conf_int_coef()
 {
   using namespace GNU_gama::local;
