@@ -1,6 +1,6 @@
 /*
     GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2000, 2002  Ales Cepek <cepek@fsv.cvut.cz>
+    Copyright (C) 2000, 2002, 2013  Ales Cepek <cepek@fsv.cvut.cz>
 
     This file is part of the GNU Gama C++ library.
 
@@ -122,6 +122,7 @@ namespace GNU_gama { namespace local {
           case tag_s_distance: return process_sdistance(atts);
           case tag_z_angle   : return process_zangle(atts);
           case tag_dh        : return process_obs_dh(atts);
+          case tag_azimuth   : return process_azimuth(atts);
           case tag_cov_mat   : return process_obs_cov(atts);
           default:
             return error(T_GKF_e01a_illegal_tag + string(cname) +
@@ -214,6 +215,9 @@ namespace GNU_gama { namespace local {
       case state_obs_dh:
         state = state_obs;
         break;
+      case state_obs_azimuth:
+        state = state_obs;
+        break;
       case state_obs_cov:
         state = state_obs_after_cov;
         break;
@@ -301,6 +305,7 @@ namespace GNU_gama { namespace local {
       {
       case 'a':
         if (!strcmp(c, "angle"              )) return tag_angle;
+        if (!strcmp(c, "azimuth"            )) return tag_azimuth;
         break;
       case 'c':
         if (!strcmp(c, "coordinates"        )) return tag_coordinates;
@@ -313,7 +318,7 @@ namespace GNU_gama { namespace local {
         if (!strcmp(c, "distance"           )) return tag_distance;
         break;
       case 'g':
-        if (!strcmp(c, "gama-local"           )) return tag_gama_xml;
+        if (!strcmp(c, "gama-local"         )) return tag_gama_xml;
         break;
       case 'h':
         if (!strcmp(c, "height-differences" )) return tag_height_differences;
@@ -528,12 +533,18 @@ namespace GNU_gama { namespace local {
 
   int GKFparser::process_point_obs(const char** atts)
   {
+    state = state_point_obs;
+
     // setting values of implicit standard deviations to "undefined";
     // on reaching end tag </points-observations> this state is
     // ignored
 
-    string nam, val, sds_abc, sds, sdk, sde, ss="0", su="0", sz="0";
-    state = state_point_obs;
+    // parameters for implicit stdev for distance
+    string nam, val, sds_abc, sds, sdk, sde;
+
+    // implicit standard deviations for direction, angle, zenit-angle, azimuth
+    string str_dir="0", str_ang="0", str_zen="0", str_azi="0";
+
 
     while (*atts)
       {
@@ -555,9 +566,10 @@ namespace GNU_gama { namespace local {
             if (i != val.end())
               return error(T_GKF_bad_attribute_distance_dev + sds_abc);
           }
-        else if (nam == "direction-stdev"   ) ss = val;
-        else if (nam == "angle-stdev"       ) su = val;
-        else if (nam == "zenith-angle-stdev") sz = val;
+        else if (nam == "direction-stdev"   ) str_dir = val;
+        else if (nam == "angle-stdev"       ) str_ang = val;
+        else if (nam == "zenith-angle-stdev") str_zen = val;
+        else if (nam == "azimuth-stdev")      str_azi = val;
         else
           return error(T_GKF_undefined_attribute_of_points_observations
                        + nam + " = " + val);
@@ -566,16 +578,18 @@ namespace GNU_gama { namespace local {
     if (sds == "") sds = "0";
     if (sdk == "") sdk = "0";
     if (sde == "") sde = "1";
-    if (!toDouble(sds, delka_str)    ||
-        !toDouble(sdk, delka_str_km) ||
-        !toDouble(sde, delka_str_exp))
+    if (!toDouble(sds, distance_stdev_)    ||
+        !toDouble(sdk, distance_stdev_km_) ||
+        !toDouble(sde, distance_stdev_exp_))
       return error(T_GKF_bad_attribute_distance_dev  + sds_abc);
-    if (!toDouble(ss, smer_str))
-      return error(T_GKF_bad_attribute_direction_dev + ss );
-    if (!toDouble(su, uhel_str))
-      return error(T_GKF_bad_attribute_angle_dev     + su );
-    if (!toDouble(sz, z_uhel_str))
-      return error(T_GKF_bad_attribute_angle_dev     + sz );
+    if (!toDouble(str_dir, direction_stdev_))
+      return error(T_GKF_bad_attribute_direction_dev + str_dir);
+    if (!toDouble(str_ang, angle_stdev_))
+      return error(T_GKF_bad_attribute_angle_dev     + str_ang);
+    if (!toDouble(str_zen, zenith_stdev_))
+      return error(T_GKF_bad_attribute_angle_dev     + str_zen);
+    if (!toDouble(str_azi, azimuth_stdev_))
+      return error(T_GKF_bad_attribute_angle_dev     + str_azi);
 
     return 0;
   }
@@ -1105,6 +1119,66 @@ namespace GNU_gama { namespace local {
 
 
 
+  int GKFparser::process_azimuth(const char** atts)
+  {
+    bool degrees = false;
+    string nam, val, sc, sm, ss, hf, ht;
+    state = state_obs_azimuth;
+
+    while (*atts)
+      {
+        nam = string(*atts++);
+        val = string(*atts++);
+
+        if      (nam == "to"     ) sc = val;
+        else if (nam == "val"    ) sm = val;
+        else if (nam == "stdev"  ) ss = val;
+        else if (nam == "from_dh") hf = val;
+        else if (nam == "to_dh"  ) ht = val;
+        else return error(T_GKF_undefined_attribute_of_azimuth
+                          + nam + " = "+val);
+      }
+
+    if (standpoint_id == "") return error(T_GKF_missing_standpoint_id);
+    if (sc   == "") return error(T_GKF_missing_forepoint_id);
+    if (sm   == "") return error(T_GKF_missing_observed_value);
+
+    double dm;
+    if (GNU_gama::deg2gon(sm, dm))
+      degrees = true;
+    else
+      if (!toDouble(sm, dm)) return error(T_GKF_bad_azimuth + sm);
+
+    double ds = implicit_stdev_azimuth();
+    if (ss != "")
+      if (!toDouble(ss, ds)) return error(T_GKF_illegal_standard_deviation);
+    double df = obs_from_dh;
+    if (hf != "")
+      if (!toDouble(hf, df))
+        return error(T_GKF_bad_instrument_reflector_height + hf);
+    double dt = 0;
+    if (ht != "")
+      if (!toDouble(ht, dt))
+        return error(T_GKF_bad_instrument_reflector_height + ht);
+
+    try
+      {
+        Azimuth* d = new Azimuth(standpoint_id, sc, dm*G2R);
+        d->set_from_dh(df);
+        d->set_to_dh(dt);
+        standpoint->observation_list.push_back( d );
+        sigma.push_back(DB_pair(ds, degrees));
+      }
+    catch (const /*GNU_gama::local::*/Exception &e)
+      {
+        error(e.what());
+      }
+
+    return 0;
+  }
+
+
+
   int GKFparser::process_obs_dh(const char** atts)
   {
     /*  the function body was copied from process_dh(const char**)  */
