@@ -2,6 +2,7 @@
     GNU Gama C++ library
     Copyright (C) 2006, 2010  Ales Cepek <cepek@gnu.org>
                   2011  Vaclav Petras <wenzeslaus@gmail.com>
+                  2012, 2013  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library
 
@@ -56,11 +57,19 @@ using GNU_gama::local::S_Distance;
 using GNU_gama::local::Xdiff;
 using GNU_gama::local::Ydiff;
 using GNU_gama::local::Zdiff;
+using GNU_gama::local::Azimuth;
 
+// undefine macro VERSION defined in gama-q2 project
+#ifdef VERSION
+#undef VERSION
+#endif
 
 namespace
 {
   const char* const VERSION = "0.5";
+
+  // maximal possible precision needed by 'make check' test rule
+  int make_check_precision(int) { return 16; }
 }
 
 /** \brief Writes observations XML representation to stream.
@@ -233,6 +242,19 @@ public:
 
       tag_from_to(obs);
     }
+    void visit(Azimuth* obs)
+    {
+      out << "<" << (tag="azimuth") << ">";
+      ostr->precision(angular);
+      double m = R2G*(obs->value());
+      *ostr << " <obs>" << m << "</obs>";
+      m += v(i)/10000;
+      if (m < 0) m += 400;
+      if (m >= 400) m -= 400;
+      *ostr << " <adj>" <<  m << "</adj>";
+
+      tag_from_to(obs);
+    }
 
     void tag_id(const GNU_gama::local::Observation* obs)
     {
@@ -381,7 +403,7 @@ void LocalNetworkXML::observations_summary(std::ostream& out) const
   public:
       ObservationSummaryCounter() :
           dirs(0),  angles(0), dists(0), coords(0),
-              hdiffs(0), zangles(0), chords(0), vectors(0)
+          hdiffs(0), zangles(0), chords(0), vectors(0), azimuth(0)
       {}
 
       void visit(Direction*)  { dirs++; }
@@ -396,9 +418,11 @@ void LocalNetworkXML::observations_summary(std::ostream& out) const
       void visit(Xdiff*)      { vectors++; }
       void visit(Ydiff*)      { }
       void visit(Zdiff*)      { }
+      void visit(Azimuth*)    { azimuth++; }
 
       int dirs,  angles, dists, coords,
-        hdiffs, zangles, chords, vectors;
+        hdiffs, zangles, chords, vectors,
+        azimuth;
   };
 
   ObservationSummaryCounter counter;
@@ -414,6 +438,7 @@ void LocalNetworkXML::observations_summary(std::ostream& out) const
   tagnl(out, "z-angles",   counter.zangles);
   tagnl(out, "s-dists",    counter.chords);
   tagnl(out, "vectors",    counter.vectors);
+  tagnl(out, "azimuths",   counter.azimuth);
 
   out << "</observations-summary>\n";
 
@@ -487,23 +512,24 @@ void LocalNetworkXML::std_dev_summary(std::ostream& out) const
     const int dof = netinfo->degrees_of_freedom();
     float test=0, lower=0, upper=0;
 
-    test  = netinfo->m_0() / netinfo->apriori_m_0();
+    test  = netinfo->m_0_aposteriori_value() / netinfo->apriori_m_0();
     if (dof)
-      if (netinfo->m_0_aposteriori())
+      //if (netinfo->m_0_aposteriori())
         {
           const double alfa_pul = (1 - netinfo->conf_pr())/2;
           lower = sqrt(GNU_gama::Chi_square(1-alfa_pul,dof)/dof);
           upper = sqrt(GNU_gama::Chi_square(  alfa_pul,dof)/dof);
         }
-      else
+      /* else
         {
           out << "   <!-- no test for apriori standard deviation -->\n";
-        }
+        } */
 
     tagnl(out, "ratio",  test);
     tagnl(out, "lower",  lower);
     tagnl(out, "upper",  upper);
-    if (lower < test && test < upper || netinfo->m_0_apriori())
+    //if (lower < test && test < upper || netinfo->m_0_apriori())
+    if (lower < test && test < upper)
       out << "   <passed/>\n\n";
     else
       out << "   <failed/>\n\n";
@@ -604,6 +630,8 @@ void LocalNetworkXML::coordinates(std::ostream& out) const
   out << "\n<!-- capital X,Y,Z denote constrained coordinates -->\n"
       << "<adjusted>\n";
 
+  out.precision(make_check_precision(6));
+
   for (PointData::const_iterator
          i=netinfo->PD.begin(); i!=netinfo->PD.end(); ++i)
     {
@@ -769,9 +797,8 @@ void LocalNetworkXML::observations(std::ostream& out) const
    const double   scale  = netinfo->gons() ? 1.0 : 0.324;
    const double   kki    = netinfo->conf_int_coef();
 
-
-   const int linear  =  6;    // output precision
-   const int angular =  7;    // output precision
+   const int linear  =  make_check_precision(6);    // output precision
+   const int angular =  make_check_precision(7);    // output precision
 
 
    WriteXMLVisitor writeVisitor(out, linear, angular, v, y_sign);
@@ -811,7 +838,9 @@ void LocalNetworkXML::observations(std::ostream& out) const
        else if (dynamic_cast<Z_Angle*>(pm))
          ml *= scale;
 
+       out.precision(make_check_precision(3));
        out << " <stdev>" << ml << "</stdev>\n";
+       out.precision(3);
 
        // weight coefficient of the residual
        double qrr = netinfo->wcoef_res(i);
