@@ -19,16 +19,12 @@
     Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-/*
- *  $Id: localnetwork.h,v 1.2 2007/06/26 15:04:11 cepek Exp $
- */
-
 #ifndef GNU_gama__xml__localnetwork__gnugamaxmllocalnetwork______________h
 #define GNU_gama__xml__localnetwork__gnugamaxmllocalnetwork______________h
 
-#include <gamalib/local/gamadata.h>
-#include <gamalib/local/network.h>
-#include <gamalib/cluster.h>
+#include <gnu_gama/local/gamadata.h>
+#include <gnu_gama/local/network.h>
+#include <gnu_gama/local/cluster.h>
 #include <string>
 
 
@@ -38,14 +34,12 @@ namespace GNU_gama
   {
   public:
 
-    std::string description;
-
-    LocalNetworkXML(GaMaLib::LocalNetwork* ln) : netinfo(ln) {}    
+    LocalNetworkXML(GNU_gama::local::LocalNetwork* ln) : netinfo(ln) {}
     void write(std::ostream&) const;
-    
+
   private:
 
-    GaMaLib::LocalNetwork* netinfo;
+    GNU_gama::local::LocalNetwork* netinfo;
 
     void coordinates_summary (std::ostream&) const;
     void observations_summary(std::ostream&) const;
