@@ -1,6 +1,6 @@
 /*
     GNU Gama -- adjustment of geodetic networks
-    Copyright (C) 2006  Ales Cepek <cepek@gnu.org>
+    Copyright (C) 2006, 2012  Ales Cepek <cepek@gnu.org>
 
     This file is part of the GNU Gama C++ library.
 
@@ -26,10 +26,65 @@
 #include <sstream>
 #include <gnu_gama/xml/localnetwork_adjustment_results.h>
 #include <gnu_gama/intfloat.h>
+#include <gnu_gama/xml/htmlparser.h>
 
 using namespace std;
 using namespace GNU_gama;
 
+void LocalNetworkAdjustmentResults::init()
+{
+  gons = true;
+
+  description.clear();
+
+  network_general_parameters.gama_local_version.  clear();
+  network_general_parameters.gama_local_algorithm.clear();
+  network_general_parameters.gama_local_compiler. clear();
+  network_general_parameters.epoch.  clear();
+  network_general_parameters.axes_xy.clear();
+  network_general_parameters.angles. clear();
+
+  coordinates_summary.adjusted.xyz = 0;
+  coordinates_summary.adjusted.xy  = 0;
+  coordinates_summary.adjusted.z   = 0;
+  coordinates_summary.constrained.xyz = 0;
+  coordinates_summary.constrained.xy  = 0;
+  coordinates_summary.constrained.z   = 0;
+  coordinates_summary.fixed.xyz = 0;
+  coordinates_summary.fixed.xy  = 0;
+  coordinates_summary.fixed.z   = 0;
+
+  observations_summary.distances = 0;
+  observations_summary.directions = 0;
+  observations_summary.angles = 0;
+  observations_summary.xyz_coords = 0;
+  observations_summary.h_diffs = 0;
+  observations_summary.z_angles = 0;
+  observations_summary.s_dists = 0;
+  observations_summary.vectors = 0;
+  observations_summary.azimuths = 0;
+
+  project_equations.equations = 0;
+  project_equations.unknowns = 0;
+  project_equations.degrees_of_freedom = 0;
+  project_equations.defect = 0;
+  project_equations.sum_of_squares = 0;
+  project_equations.connected_network = true;
+
+  standard_deviation.apriori = 0;
+  standard_deviation.aposteriori = 0;
+  standard_deviation.using_aposteriori = true;
+  standard_deviation.probability = 0;
+  standard_deviation.ratio = 0;
+  standard_deviation.lower = 0;
+  standard_deviation.upper = 0;
+  standard_deviation.passed = false;
+  standard_deviation.confidence_scale = 0;
+
+  fixed_points      .clear();
+  approximate_points.clear();
+  adjusted_points   .clear();
+}
 
 double LocalNetworkAdjustmentResults::Observation::residual() const
   throw()
@@ -61,6 +116,42 @@ void LocalNetworkAdjustmentResults::read_xml(std::istream& xml)
 }
 
 
+void LocalNetworkAdjustmentResults::read_html(std::istream& html)
+  throw(GNU_gama::Exception::parser)
+{
+  GNU_gama::HtmlParser parser(this);
+  {
+    std::string line;
+    while (std::getline(html, line, '\0'))
+      {
+        std::string text;
+        for (int i=0; i<line.length(); i++)
+          {
+            // replace some special hardcoded characters used in
+            // gama-local HTML output for better formatting
+            if (line[i] == '&')
+              {
+                if (line.substr(i, 6) == "&nbsp;")
+                  {
+                    text += ' ';
+                    i += 5;
+                    continue;
+                  }
+                if (line.substr(i, 7) == "&minus;")
+                  {
+                    text += '-';
+                    i += 6;
+                    continue;
+                  }
+              }
+            text += line[i];
+          }
+        parser.xml_parse(text.c_str(), text.length(), 0);
+     }
+    parser.xml_parse("", 0, 1);
+  }
+}
+
 void LocalNetworkAdjustmentResults::Parser::check_and_clear_data()
 {
   for (std::string::const_iterator
@@ -102,6 +193,7 @@ void LocalNetworkAdjustmentResults::Parser::init()
   tagfun[s_h_diffs_end                        ][t_z_angles                       ] = &Parser::z_angles;
   tagfun[s_z_angles_end                       ][t_s_dists                        ] = &Parser::s_dists;
   tagfun[s_s_dists_end                        ][t_vectors                        ] = &Parser::vectors;
+  tagfun[s_vectors_end                        ][t_azimuths                       ] = &Parser::azimuths;
   tagfun[s_observations_summary_end           ][t_project_equations              ] = &Parser::project_equations;
   tagfun[s_project_equations                  ][t_equations                      ] = &Parser::equations;
   tagfun[s_equations_end                      ][t_unknowns                       ] = &Parser::unknowns;
@@ -167,6 +259,7 @@ void LocalNetworkAdjustmentResults::Parser::init()
   tagfun[s_observations                       ][t_angle                          ] = &Parser::observation;
   tagfun[s_observations                       ][t_slope_distance                 ] = &Parser::observation;
   tagfun[s_observations                       ][t_zenith_angle                   ] = &Parser::observation;
+  tagfun[s_observations                       ][t_azimuth                        ] = &Parser::observation;
   tagfun[s_observations                       ][t_dx                             ] = &Parser::observation;
   tagfun[s_observations                       ][t_dy                             ] = &Parser::observation;
   tagfun[s_observations                       ][t_dz                             ] = &Parser::observation;
@@ -198,6 +291,8 @@ int LocalNetworkAdjustmentResults::Parser::tag(const char* c)
       if (!strcmp(c, "aposteriori"               )) return t_aposteriori;
       if (!strcmp(c, "approx"                    )) return t_approx;
       if (!strcmp(c, "approximate"               )) return t_approximate;
+      if (!strcmp(c, "azimuth"                   )) return t_azimuth;
+      if (!strcmp(c, "azimuths"                  )) return t_azimuths;
       break;
     case 'b':
       if (!strcmp(c, "band"                      )) return t_band;
@@ -712,6 +807,21 @@ void LocalNetworkAdjustmentResults::Parser::vectors(bool start)
 }
 
 
+void LocalNetworkAdjustmentResults::Parser::azimuths(bool start)
+{
+  if (start)
+    {
+      stack.push(&Parser::azimuths);
+      set_state(s_azimuths);
+    }
+  else
+    {
+      adj->observations_summary.azimuths = get_int();
+      set_state(s_azimuths_end);
+    }
+}
+
+
 void LocalNetworkAdjustmentResults::Parser::project_equations(bool start)
 {
   if (start)
@@ -1565,5 +1675,3 @@ void LocalNetworkAdjustmentResults::Parser::err_adj(bool start)
       set_state(s_err_adj_end);
     }
 }
-
-
